==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/config/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi@gmail.com>
 * @author SandorTIHANYI <stihanyi@gmail.com>
 */
$lang['menu']                  = 'Beállító Központ';
$lang['error']                 = 'Helytelen érték miatt a módosítások nem mentődtek. Nézd át a módosításokat, és ments újra.
<br />A helytelen érték(ek)et piros kerettel jelöljük.';
$lang['updated']               = 'A módosítások sikeresen beállítva.';
$lang['nochoice']              = '(nincs egyéb lehetőség)';
$lang['locked']                = 'A beállításokat tartalmazó fájlt nem tudtam frissíteni.<br />
Nézd meg, hogy a fájl neve és jogosultságai helyesen vannak-e beállítva!';
$lang['_configuration_manager'] = 'Beállító Központ';
$lang['_header_dokuwiki']      = 'DokuWiki beállítások';
$lang['_header_plugin']        = 'Bővítmények beállításai';
$lang['_header_template']      = 'Sablon beállítások';
$lang['_header_undefined']     = 'Nem definiált értékek';
$lang['_basic']                = 'Alap beállítások';
$lang['_display']              = 'Megjelenítés beállításai';
$lang['_authentication']       = 'Azonosítás beállításai';
$lang['_anti_spam']            = 'Annti-Spam beállítások';
$lang['_editing']              = 'Szerkesztési beállítások';
$lang['_links']                = 'Link beállítások';
$lang['_media']                = 'Media beállítások';
$lang['_advanced']             = 'Haladó beállítások';
$lang['_network']              = 'Hálózati beállítások';
$lang['_plugin_sufix']         = 'Bővítmények beállításai';
$lang['_template_sufix']       = 'Sablon beállítások';
$lang['_msg_setting_undefined'] = 'Nincs beállított meta-adat.';
$lang['_msg_setting_no_class'] = 'Nincs beállított osztály.';
$lang['_msg_setting_no_default'] = 'Nincs alapértelmezett érték.';
$lang['fmode']                 = 'Fájl létrehozási maszk';
$lang['dmode']                 = 'Könyvtár létrehozási maszk';
$lang['lang']                  = 'Nyelv';
$lang['basedir']               = 'Báziskönyvtár';
$lang['baseurl']               = 'Alap URL';
$lang['savedir']               = 'Könyvtár az adatok mentésére';
$lang['start']                 = 'Kezdőoldal neve';
$lang['title']                 = 'Wiki címe';
$lang['template']              = 'Sablon';
$lang['fullpath']              = 'Az oldalak teljes útvonalának mutatása a láblécben';
$lang['recent']                = 'Utolsó változatok száma';
$lang['breadcrumbs']           = 'Nyomvonal elemszám';
$lang['youarehere']            = 'Hierarchikus nyomvonal';
$lang['typography']            = 'Legyen-e tipográfiai csere';
$lang['htmlok']                = 'Beágyazott HTML engedélyezése';
$lang['phpok']                 = 'Beágyazott PHP engedélyezése';
$lang['dformat']               = 'Dátum formázás (lásd a PHP <a href="http://www.php.net/strftime">strftime</a> függvényt)';
$lang['signature']             = 'Aláírás';
$lang['toptoclevel']           = 'A tartalomjegyzék felső szintje';
$lang['maxtoclevel']           = 'A tartalomjegyzék mélysége';
$lang['maxseclevel']           = 'A szakasz-szerkesztés maximális szintje';
$lang['camelcase']             = 'CamelCase használata hivatkozásként';
$lang['deaccent']              = 'Oldalnevek ékezettelenítése';
$lang['useheading']            = 'Az első fejléc legyen az oldalnév';
$lang['refcheck']              = 'Médiafájlok hivatkozásainak ellenőrzése';
$lang['refshow']               = 'Média-hivatkozások maximálisan mutatott szintje';
$lang['allowdebug']            = 'Debug üzemmód <b>Kapcsold ki, hacsak biztos nem szükséges!</b>';
$lang['usewordblock']          = 'Szólista alapú spam-szűrés';
$lang['indexdelay']            = 'Várakozás indexelés előtt (másodperc)';
$lang['relnofollow']           = 'rel="nofollow" beállítás használata külső hivatkozásokra';
$lang['mailguard']             = 'Email címek olvashatatlanná tétele címgyűjtők számára';
$lang['iexssprotect']          = 'Feltöltött fájlok ellenőrzése kártékony JavaScript vagy HTML kód elkerülésére';
$lang['useacl']                = 'Hozzáférési listák (ACL) használata';
$lang['autopasswd']            = 'Jelszavak automatikus generálása';
$lang['authtype']              = 'Authentikációs háttérrendszer';
$lang['passcrypt']             = 'Jelszó titkosítási módszer';
$lang['defaultgroup']          = 'Alapértelmezett csoport';
$lang['superuser']             = 'Szuper-felhasználó (Wiki-gazda) - csoport vagy felhasználó, aki teljes hozzáférési joggal rendelkezik az oldalakhoz és funkciókhoz, a hozzáférési jogosultságoktól függetlenül';
$lang['manager']               = 'Menedzser - csoport vagy felhasználó, aki bizonyos menedzsment funkciókhoz hozzáfér';
$lang['profileconfirm']        = 'Beállítások változtatásának megerősítése jelszóval';
$lang['disableactions']        = 'Bizonyos DokuWiki tevékenységek (action) tiltása';
$lang['disableactions_check']  = 'Ellenőrzés';
$lang['disableactions_subscription'] = 'Feliratkozás/Leiratkozás';
$lang['disableactions_nssubscription'] = 'Névtér feliratkozás/Leiratkozás';
$lang['disableactions_wikicode'] = 'Forrás megtekintése/Nyers adat exportja';
$lang['disableactions_other']  = 'Egyéb tevékenységek (vesszővel elválasztva)';
$lang['sneaky_index']          = 'Alapértelmezetten minden névtér látszik a DokuWiki áttekintő (index) oldalán. Ezen opció bekapcsolása után azok nem jelennek meg, melyekhez a felhasználónak nincs olvasás joga. De ezzel eltakarhatunk egyébként elérhető al-névtereket is, így bizonyos ACL beállításoknál használhatatlan indexet eredményez ez a beállítás.';
$lang['auth_security_timeout'] = 'Authentikációs biztonsági időablak (másodperc)';
$lang['updatecheck']           = 'Frissítések és biztonsági figyelmeztetések figyelése. Ehhez a DokuWikinek kapcsolatba kell lépnie a splitbrain.org-gal.';
$lang['userewrite']            = 'Szép URL-ek használata';
$lang['useslash']              = 'Per-jel használata névtér-elválasztóként az URL-ekben';
$lang['usedraft']              = 'Piszkozat automatikus mentése szerkesztés alatt';
$lang['sepchar']               = 'Szó elválasztó az oldalnevekben';
$lang['canonical']             = 'Teljesen kanonikus URL-ek használata';
$lang['autoplural']            = 'Többes szám ellenőrzés a hivatkozásokban (angol)';
$lang['compression']           = 'Tömörítés használata a törölt lapokhoz';
$lang['cachetime']             = 'A gyorsítótár maximális élettartama (másodperc)';
$lang['locktime']              = 'Oldal-zárolás maximális időtartama (másodperc)';
$lang['fetchsize']             = 'Maximális méret (bájtban), amit a fetch.php letölthet kívülről';
$lang['notify']                = 'Az oldal-változásokat erre az e-mail címre küldje';
$lang['registernotify']        = 'Értesítés egy újonnan regisztrált felhasználóról erre az e-mail címre';
$lang['mailfrom']              = 'Az automatikusan küldött levelekben használt e-mail cím';
$lang['gzip_output']           = 'gzip tömörítés használata xhtml-hez (Content-Encoding)';
$lang['gdlib']                 = 'GD Lib verzió';
$lang['im_convert']            = 'Útvonal az ImageMagick csomag convert parancsához';
$lang['jpg_quality']           = 'JPG tömörítés minősége (0-100)';
$lang['subscribers']           = 'Oldalváltozás-listára feliratkozás engedélyezése';
$lang['compress']              = 'CSS és JavaScript fájlok tömörítése';
$lang['hidepages']             = 'Az itt megadott oldalak elrejtése (regularis kifejezés)';
$lang['send404']               = '"HTTP 404/Page Not Found" küldése nemlétező oldalak esetén';
$lang['sitemap']               = 'Hány naponként generáljunk Google sitemap-ot?';
$lang['broken_iua']            = 'Az ignore_user_abort függvény hibát dob a rendszereden? Ez nem működő keresési indexet eredményezhet. Az IIS+PHP/CGI összeállításról tudjuk, hogy hibát dob. Lásd a <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> oldalt a további infóért.';
$lang['xsendfile']             = 'Használjuk az X-Sendfile fejlécet, hogy a webszerver statikus állományokat tudjon küldeni? A webszervernek is támogatnia kell ezt a funkciót.';
$lang['xmlrpc']                = 'XML-RPC interfész engedélyezése/tiltása';
$lang['renderer_xhtml']        = 'Az elsődleges (xhtml) wiki kimenet generálója';
$lang['renderer__core']        = '%s (dokuwiki mag)';
$lang['renderer__plugin']      = '%s (bővítmény)';
$lang['rss_type']              = 'XML hírfolyam típus';
$lang['rss_linkto']            = 'XML hírfolyam hivatkozás';
$lang['rss_content']           = 'Mit mutassunk az XML hírfolyam elemekben?';
$lang['rss_update']            = 'Hány másodpercenként frissítsük az XML hírfolyamot?';
$lang['recent_days']           = 'Hány napig tartsuk meg a korábbi változatokat?';
$lang['rss_show_summary']      = 'A hírfolyam címébe összefoglaló helyezése';
$lang['target____wiki']        = 'Cél-ablak belső hivatkozásokhoz';
$lang['target____interwiki']   = 'Cél-ablak interwiki hivatkozásokhoz';
$lang['target____extern']      = 'Cél-ablak külső hivatkozásokhoz';
$lang['target____media']       = 'Cél-ablak média-fájl hivatkozásokhoz';
$lang['target____windows']     = 'Cél-ablak Windows hivatkozásokhoz';
$lang['proxy____host']         = 'Proxy szerver neve';
$lang['proxy____port']         = 'Proxy port';
$lang['proxy____user']         = 'Proxy felhasználó név';
$lang['proxy____pass']         = 'Proxy jelszó';
$lang['proxy____ssl']          = 'SSL használata a proxyhoz csatlakozáskor';
$lang['safemodehack']          = 'safemode hack engedélyezése';
$lang['ftp____host']           = 'FTP szerver a safemode hack-hez';
$lang['ftp____port']           = 'FTP port a safemode hack-hez';
$lang['ftp____user']           = 'FTP felhasználó név a safemode hack-hez';
$lang['ftp____pass']           = 'FTP jelszó a safemode hack-hez';
$lang['ftp____root']           = 'FTP gyökérkönyvtár a safemode hack-hez';
$lang['typography_o_0']        = 'nem';
$lang['typography_o_1']        = 'Csak a dupla idézőjelet';
$lang['typography_o_2']        = 'Minden idézőjelet (előfordulhat, hogy nem mindig működik)';
$lang['userewrite_o_0']        = 'nem';
$lang['userewrite_o_1']        = '.htaccess-szel';
$lang['userewrite_o_2']        = 'DokuWiki saját módszerével';
$lang['deaccent_o_0']          = 'kikapcsolva';
$lang['deaccent_o_1']          = 'ékezetek eltávolítása';
$lang['deaccent_o_2']          = 'távirati stílus';
$lang['gdlib_o_0']             = 'GD Lib nem elérhető';
$lang['gdlib_o_1']             = 'Version 1.x';
$lang['gdlib_o_2']             = 'Auto felismerés';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Kivonat';
$lang['rss_content_o_diff']    = 'Unified diff formátum';
$lang['rss_content_o_htmldiff'] = 'HTML formázott változás tábla';
$lang['rss_content_o_html']    = 'Teljes HTML oldal tartalom';
$lang['rss_linkto_o_diff']     = 'a változás nézetre';
$lang['rss_linkto_o_page']     = 'az átdolgozott oldalra';
$lang['rss_linkto_o_rev']      = 'a változatok listájára';
$lang['rss_linkto_o_current']  = 'a jelenlegi oldalra';
$lang['compression_o_0']       = 'nincs tömörítés';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'nincs használatban';
$lang['xsendfile_o_1']         = 'lighttpd saját fejléc (1.5-ös verzió előtti)';
$lang['xsendfile_o_2']         = 'Standard X-Sendfile fejléc';
$lang['xsendfile_o_3']         = 'Nginx saját X-Accel-Redirect fejléce';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/config/lang/hu/lang.php <==
<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 */
$lang['menu']                  = 'Beállító Központ';
$lang['error']                 = 'Helytelen érték miatt a módosítások nem mentődtek. Nézd át a módosításokat, és ments újra.
<br />A helytelen érték(ek)et piros kerettel jelöljük.';
$lang['updated']               = 'A módosítások sikeresen beállítva.';
$lang['nochoice']              = '(nincs egyéb lehetőség)';
$lang['locked']                = 'A beállításokat tartalmazó fájlt nem tudtam frissíteni.<br />
Nézd meg, hogy a fájl neve és jogosultságai helyesen vannak-e beállítva!';
$lang['_configuration_manager'] = 'Beállító Központ';
$lang['_header_dokuwiki']      = 'DokuWiki beállítások';
$lang['_header_plugin']        = 'Bővítmények beállításai';
$lang['_header_template']      = 'Sablon beállítások';
$lang['_header_undefined']     = 'Nem definiált értékek';
$lang['_basic']                = 'Alap beállítások';
$lang['_display']              = 'Megjelenítés beállításai';
$lang['_authentication']       = 'Azonosítás beállításai';
$lang['_anti_spam']            = 'Anti-Spam beállítások';
$lang['_editing']              = 'Szerkesztési beállítások';
$lang['_links']                = 'Link beállítások';
$lang['_media']                = 'Media beállítások';
$lang['_advanced']             = 'Haladó beállítások';
$lang['_network']              = 'Hálózati beállítások';
$lang['_plugin_sufix']         = 'Bővítmények beállításai';
$lang['_template_sufix']       = 'Sablon beállítások';
$lang['_msg_setting_undefined'] = 'Nincs beállított meta-adat.';
$lang['_msg_setting_no_class'] = 'Nincs beállított osztály.';
$lang['_msg_setting_no_default'] = 'Nincs alapértelmezett érték.';
$lang['fmode']                 = 'Fájl létrehozási maszk';
$lang['dmode']                 = 'Könyvtár létrehozási maszk';
$lang['lang']                  = 'Nyelv';
$lang['basedir']               = 'Báziskönyvtár';
$lang['baseurl']               = 'Alap URL';
$lang['savedir']               = 'Könyvtár az adatok mentésére';
$lang['start']                 = 'Kezdőoldal neve';
$lang['title']                 = 'Wiki címe';
$lang['template']              = 'Sablon';
$lang['license']               = 'Milyen licenc alatt érhető el a tartalom?';
$lang['fullpath']              = 'Az oldalak teljes útvonalának mutatása a láblécben';
$lang['recent']                = 'Utolsó változatok száma';
$lang['breadcrumbs']           = 'Nyomvonal elemszám';
$lang['youarehere']            = 'Hierarchikus nyomvonal';
$lang['typography']            = 'Legyen-e tipográfiai csere';
$lang['htmlok']                = 'Beágyazott HTML engedélyezése';
$lang['phpok']                 = 'Beágyazott PHP engedélyezése';
$lang['dformat']               = 'Dátum formázás (lásd a PHP <a href="http://www.php.net/strftime">strftime</a> függvényt)';
$lang['signature']             = 'Aláírás';
$lang['toptoclevel']           = 'A tartalomjegyzék felső szintje';
$lang['tocminheads']           = 'Legalább ennyi címsor hatására generálódjon tartalomjegyzék';
$lang['maxtoclevel']           = 'A tartalomjegyzék mélysége';
$lang['maxseclevel']           = 'A szakasz-szerkesztés maximális szintje';
$lang['camelcase']             = 'CamelCase használata hivatkozásként';
$lang['deaccent']              = 'Oldalnevek ékezettelenítése';
$lang['useheading']            = 'Az első fejléc legyen az oldalnév';
$lang['refcheck']              = 'Médiafájlok hivatkozásainak ellenőrzése';
$lang['refshow']               = 'Média-hivatkozások maximálisan mutatott szintje';
$lang['allowdebug']            = 'Debug üzemmód <b>Kapcsold ki, hacsak biztos nem szükséges!</b>';
$lang['usewordblock']          = 'Szólista alapú spam-szűrés';
$lang['indexdelay']            = 'Várakozás indexelés előtt (másodperc)';
$lang['relnofollow']           = 'rel="nofollow" beállítás használata külső hivatkozásokra';
$lang['mailguard']             = 'Email címek olvashatatlanná tétele címgyűjtők számára';
$lang['iexssprotect']          = 'Feltöltött fájlok ellenőrzése kártékony JavaScript vagy HTML kód elkerülésére';
$lang['showuseras']            = 'A felhasználó melyik adatát mutassunk az utolsó változtatás adatainál?';
$lang['useacl']                = 'Hozzáférési listák (ACL) használata';
$lang['autopasswd']            = 'Jelszavak automatikus generálása';
$lang['authtype']              = 'Authentikációs háttérrendszer';
$lang['passcrypt']             = 'Jelszó titkosítási módszer';
$lang['defaultgroup']          = 'Alapértelmezett csoport';
$lang['superuser']             = 'Szuper-felhasználó (Wiki-gazda) - csoport vagy felhasználó, aki teljes hozzáférési joggal rendelkezik az oldalakhoz és funkciókhoz, a hozzáférési jogosultságoktól függetlenül';
$lang['manager']               = 'Menedzser - csoport vagy felhasználó, aki bizonyos menedzsment funkciókhoz hozzáfér';
$lang['profileconfirm']        = 'Beállítások változtatásának megerősítése jelszóval';
$lang['disableactions']        = 'Bizonyos DokuWiki tevékenységek (action) tiltása';
$lang['disableactions_check']  = 'Ellenőrzés';
$lang['disableactions_subscription'] = 'Feliratkozás/Leiratkozás';
$lang['disableactions_nssubscription'] = 'Névtér feliratkozás/Leiratkozás';
$lang['disableactions_wikicode'] = 'Forrás megtekintése/Nyers adat exportja';
$lang['disableactions_other']  = 'Egyéb tevékenységek (vesszővel elválasztva)';
$lang['sneaky_index']          = 'Alapértelmezetten minden névtér látszik a DokuWiki áttekintő (index) oldalán. Ezen opció bekapcsolása után azok nem jelennek meg, melyekhez a felhasználónak nincs olvasás joga. De ezzel eltakarhatunk egyébként elérhető al-névtereket is, így bizonyos ACL beállításoknál használhatatlan indexet eredményez ez a beállítás.';
$lang['auth_security_timeout'] = 'Authentikációs biztonsági időablak (másodperc)';
$lang['securecookie']          = 'A böngészők a HTTPS felett beállított sütijüket csak HTTPS felett küldhetik? Kapcsoljuk ki ezt az opciót, ha csak a bejelentkezést védjük SSL-lel, a wiki tartalmának böngészése nyílt forgalommal történik.';
$lang['updatecheck']           = 'Frissítések és biztonsági figyelmeztetések figyelése. Ehhez a DokuWikinek kapcsolatba kell lépnie a splitbrain.org-gal.';
$lang['userewrite']            = 'Szép URL-ek használata';
$lang['useslash']              = 'Per-jel használata névtér-elválasztóként az URL-ekben';
$lang['usedraft']              = 'Piszkozat automatikus mentése szerkesztés alatt';
$lang['sepchar']               = 'Szó elválasztó az oldalnevekben';
$lang['canonical']             = 'Teljesen kanonikus URL-ek használata';
$lang['autoplural']            = 'Többes szám ellenőrzés a hivatkozásokban (angol)';
$lang['compression']           = 'Tömörítés használata a törölt lapokhoz';
$lang['cachetime']             = 'A gyorsítótár maximális élettartama (másodperc)';
$lang['locktime']              = 'Oldal-zárolás maximális időtartama (másodperc)';
$lang['fetchsize']             = 'Maximális méret (bájtban), amit a fetch.php letölthet kívülről';
$lang['notify']                = 'Az oldal-változásokat erre az e-mail címre küldje';
$lang['registernotify']        = 'Értesítés egy újonnan regisztrált felhasználóról erre az e-mail címre';
$lang['mailfrom']              = 'Az automatikusan küldött levelekben használt e-mail cím';
$lang['gzip_output']           = 'gzip tömörítés használata xhtml-hez (Content-Encoding)';
$lang['gdlib']                 = 'GD Lib verzió';
$lang['im_convert']            = 'Útvonal az ImageMagick csomag convert parancsához';
$lang['jpg_quality']           = 'JPG tömörítés minősége (0-100)';
$lang['subscribers']           = 'Oldalváltozás-listára feliratkozás engedélyezése';
$lang['compress']              = 'CSS és JavaScript fájlok tömörítése';
$lang['hidepages']             = 'Az itt megadott oldalak elrejtése (regularis kifejezés)';
$lang['send404']               = '"HTTP 404/Page Not Found" küldése nemlétező oldalak esetén';
$lang['sitemap']               = 'Hány naponként generáljunk Google sitemap-ot?';
$lang['broken_iua']            = 'Az ignore_user_abort függvény hibát dob a rendszereden? Ez nem működő keresési indexet eredményezhet. Az IIS+PHP/CGI összeállításról tudjuk, hogy hibát dob. Lásd a <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> oldalt a további infóért.';
$lang['xsendfile']             = 'Használjuk az X-Sendfile fejlécet, hogy a webszerver statikus állományokat tudjon küldeni? A webszervernek is támogatnia kell ezt a funkciót.';
$lang['xmlrpc']                = 'XML-RPC interfész engedélyezése/tiltása';
$lang['renderer_xhtml']        = 'Az elsődleges (xhtml) wiki kimenet generálója';
$lang['renderer__core']        = '%s (dokuwiki mag)';
$lang['renderer__plugin']      = '%s (bővítmény)';
$lang['rememberme']            = 'Állandó sütik engedélyezése (az "emlékezz rám" funkcióhoz)';
$lang['rss_type']              = 'XML hírfolyam típus';
$lang['rss_linkto']            = 'XML hírfolyam hivatkozás';
$lang['rss_content']           = 'Mit mutassunk az XML hírfolyam elemekben?';
$lang['rss_update']            = 'Hány másodpercenként frissítsük az XML hírfolyamot?';
$lang['recent_days']           = 'Hány napig tartsuk meg a korábbi változatokat?';
$lang['rss_show_summary']      = 'A hírfolyam címébe összefoglaló helyezése';
$lang['target____wiki']        = 'Cél-ablak belső hivatkozásokhoz';
$lang['target____interwiki']   = 'Cél-ablak interwiki hivatkozásokhoz';
$lang['target____extern']      = 'Cél-ablak külső hivatkozásokhoz';
$lang['target____media']       = 'Cél-ablak média-fájl hivatkozásokhoz';
$lang['target____windows']     = 'Cél-ablak Windows hivatkozásokhoz';
$lang['proxy____host']         = 'Proxy szerver neve';
$lang['proxy____port']         = 'Proxy port';
$lang['proxy____user']         = 'Proxy felhasználó név';
$lang['proxy____pass']         = 'Proxy jelszó';
$lang['proxy____ssl']          = 'SSL használata a proxyhoz csatlakozáskor';
$lang['safemodehack']          = 'A PHP safemode beállítás megkerülésének engedélyezése';
$lang['ftp____host']           = 'FTP szerver a safemode megkerüléshez';
$lang['ftp____port']           = 'FTP port a safemode megkerüléshez';
$lang['ftp____user']           = 'FTP felhasználó név a safemode megkerüléshez';
$lang['ftp____pass']           = 'FTP jelszó a safemode megkerüléshez';
$lang['ftp____root']           = 'FTP gyökérkönyvtár a safemode megkerüléshez';
$lang['license_o_']            = 'Nincs kiválasztva';
$lang['typography_o_0']        = 'nem';
$lang['typography_o_1']        = 'Csak a dupla idézőjelet';
$lang['typography_o_2']        = 'Minden idézőjelet (előfordulhat, hogy nem mindig működik)';
$lang['userewrite_o_0']        = 'nem';
$lang['userewrite_o_1']        = '.htaccess-szel';
$lang['userewrite_o_2']        = 'DokuWiki saját módszerével';
$lang['deaccent_o_0']          = 'kikapcsolva';
$lang['deaccent_o_1']          = 'ékezetek eltávolítása';
$lang['deaccent_o_2']          = 'távirati stílus';
$lang['gdlib_o_0']             = 'GD Lib nem elérhető';
$lang['gdlib_o_1']             = 'Version 1.x';
$lang['gdlib_o_2']             = 'Auto felismerés';
$lang['rss_type_o_rss']        = 'RSS 0.91';
$lang['rss_type_o_rss1']       = 'RSS 1.0';
$lang['rss_type_o_rss2']       = 'RSS 2.0';
$lang['rss_type_o_atom']       = 'Atom 0.3';
$lang['rss_type_o_atom1']      = 'Atom 1.0';
$lang['rss_content_o_abstract'] = 'Kivonat';
$lang['rss_content_o_diff']    = 'Unified diff formátum';
$lang['rss_content_o_htmldiff'] = 'HTML formázott változás tábla';
$lang['rss_content_o_html']    = 'Teljes HTML oldal tartalom';
$lang['rss_linkto_o_diff']     = 'a változás nézetre';
$lang['rss_linkto_o_page']     = 'az átdolgozott oldalra';
$lang['rss_linkto_o_rev']      = 'a változatok listájára';
$lang['rss_linkto_o_current']  = 'a jelenlegi oldalra';
$lang['compression_o_0']       = 'nincs tömörítés';
$lang['compression_o_gz']      = 'gzip';
$lang['compression_o_bz2']     = 'bz2';
$lang['xsendfile_o_0']         = 'nincs használatban';
$lang['xsendfile_o_1']         = 'lighttpd saját fejléc (1.5-ös verzió előtti)';
$lang['xsendfile_o_2']         = 'Standard X-Sendfile fejléc';
$lang['xsendfile_o_3']         = 'Nginx saját X-Accel-Redirect fejléce';
$lang['showuseras_o_loginname'] = 'Azonosító';
$lang['showuseras_o_username'] = 'Teljes név';
$lang['showuseras_o_email']    = 'E-mail cím (olvashatatlanná téve az e-mailcím védelem beállítása szerint)';
$lang['showuseras_o_email_link'] = 'E-mail cím mailto: linkként';
$lang['useheading_o_0']        = 'Soha';
$lang['useheading_o_navigation'] = 'Csak navigációhoz';
$lang['useheading_o_content']  = 'Csak Wiki tartalomhoz';
$lang['useheading_o_1']        = 'Mindig';
